import subprocess
import string
import random
import os
import sys
import emptydb
import importcsv

from ..utils import invalid_url

def usage(argv):
    cmd = os.path.basename(argv[0])
    print('usage: %s <config_uri> <url>\n'
          '(example: "%s development.ini")' % (cmd, cmd))
    sys.exit(1)


def main(argv=sys.argv):
    if len(argv) != 3:
        usage(argv)
    if invalid_url(argv[2]):
        print invalid_url(argv[2])
        sys.exit(1)
    filename = ''.join(random.sample(
        string.ascii_letters + string.digits, 16)) + '.csv'
    subprocess.call(["bin/linkchecker",
                    "--recursion-level=1",
                    "--file-output=csv/utf-8/" + filename,
                    "--no-warnings",
                    "--pause=3",
                    argv[2]])
    emptydb.main(argv)
    argv[2] = filename
    importcsv.main(argv)
    os.remove(filename)



import os
import sys
import transaction
import string
import random

from sqlalchemy import engine_from_config

from pyramid.paster import (
    get_appsettings,
    setup_logging,
    )

from ..models import (
    DBSession,
    CheckedLink,
    Base,
    User,
    )


def usage(argv):
    cmd = os.path.basename(argv[0])
    print('usage: %s <config_uri>\n'
          '(example: "%s development.ini")' % (cmd, cmd))
    sys.exit(1)


def main(argv=sys.argv):
    if len(argv) != 2:
        usage(argv)
    config_uri = argv[1]
    setup_logging(config_uri)
    settings = get_appsettings(config_uri)
    engine = engine_from_config(settings, 'sqlalchemy.')
    DBSession.configure(bind=engine)
    Base.metadata.create_all(engine)
    with transaction.manager:
        try:
            f = open('password.txt','r')
            data = f.read()
            un, pw = data.split(':')
            un=un.strip()
            pw=pw.strip()
            f.close()
        except:
            un = raw_input('Username [admin]: ')
            if not un:
                un = 'admin'
            pw = raw_input('Password [generate]: ')
            if not pw:
                pw = ''.join(random.sample(string.ascii_letters + string.digits, 8))
                print( 'password generated: ', pw)
            f = open('password.txt', 'w')
            data = '%s:%s' % (un, pw)
            f.write(data)
            f.close()
        fn = raw_input('Fullname: ')
        em = raw_input('Email: ')
        user = User(un, pw, fn, em)
        DBSession.add(user)




import string
import random
from pyramid.authentication import SessionAuthenticationPolicy
from pyramid.authorization import ACLAuthorizationPolicy
from pyramid.session import UnencryptedCookieSessionFactoryConfig
from pyramid.config import Configurator
from sqlalchemy import engine_from_config

from .models import (
    DBSession,
    Base,
    RootFactory,
    )


def main(global_config, **settings):
    """ This function returns a Pyramid WSGI application.
    """
    engine = engine_from_config(settings, 'sqlalchemy.')
    DBSession.configure(bind=engine)
    Base.metadata.bind = engine
    secret = ''.join(random.sample(string.ascii_letters + string.digits,
                16))
    session_factory = UnencryptedCookieSessionFactoryConfig(secret)
    authn_policy = SessionAuthenticationPolicy()
    authz_policy = ACLAuthorizationPolicy()
    config = Configurator(
        settings=settings,
        root_factory=RootFactory,
        authentication_policy=authn_policy,
        authorization_policy=authz_policy,
        session_factory=session_factory
        )
    config.add_static_view('static', 'static', cache_max_age=3600)
    config.add_route('home', '/')
    config.add_route('parenturl', '/checkurl')
    config.add_route('checkpages', '/getpages')
    config.add_route('linkcheck', '/linkcheckurl')
    config.add_route('login', '/login')
    config.add_route('logout', '/logout')
    config.add_route('register', '/register')
    config.add_route('preferences', '/preferences')
    config.add_route('linkchecks', '/linkcheck')
    config.add_route('addlinkcheck', '/linkcheck/add')
    config.add_route('editlinkcheck', '/linkcheck/{check_id}')
    config.scan()
    return config.make_wsgi_app()



import string
import random

from sqlalchemy import (
    Column,
    Integer,
    Float,
    Text,
    Unicode,
    Boolean,
    )

from sqlalchemy.ext.declarative import declarative_base

from sqlalchemy.orm import (
    scoped_session,
    sessionmaker,
    synonym,
    )

from pyramid.security import (
    Everyone,
    Authenticated,
    Allow,
    )


from zope.sqlalchemy import ZopeTransactionExtension

import cryptacular.bcrypt

DBSession = scoped_session(sessionmaker(extension=ZopeTransactionExtension()))
Base = declarative_base()


CSV_HEADER =['urlname', 'parentname', 'baseref', 'result', 'warningstring',
    'infostring', 'valid', 'url', 'line', 'column', 'name', 'dltime',
    'dlsize', 'checktime', 'cached', 'level', 'modified']

class CheckedLink(Base):
    __tablename__ = 'checked_links'
    urlid = Column(Integer, primary_key=True)
    urlname = Column(Unicode(512), nullable=False) #varchar(256) not null,
    parentname = Column(Unicode(512))               #varchar(256),
    baseref = Column(Unicode(80))                   #varchar(256),
    result = Column(Unicode(256))                   #varchar(256),
    warning = Column(Unicode(512))                  #varchar(512),
    info = Column(Unicode(512))                     #varchar(512),
    valid = Column(Unicode(80))                     #int,
    url = Column(Unicode(512))                      #varchar(256),
    line = Column(Integer)                          #int,
    col = Column(Integer)                           #int,
    name = Column(Unicode(256))                     #varchar(256),
    dltime = Column(Float)                        #int,
    dlsize = Column(Integer)                        #int,
    checktime = Column(Float)                     #int,
    cached = Column(Integer)                        #int,
    level = Column(Integer, nullable=False)        #int not null,
    modified = Column(Unicode(256))                 #varchar(256)

    def __init__(self, urlname, parentname, baseref,  result,
                warning, info, valid, url, line, col, name, dltime,
                dlsize, checktime, cached, level, modified=None):
        self.urlname = urlname
        self.parentname = parentname
        self.baseref = baseref
        self.valid = valid
        self.result = result
        self.warning = warning
        self.info = info
        self.url = url
        self.line = line
        self.col = col
        self.name = name
        self.checktime = checktime
        self.dltime = dltime
        self.dlsize = dlsize
        self.cached = cached
        self.level = level
        self.modified = modified


crypt = cryptacular.bcrypt.BCRYPTPasswordManager()

def hash_password(password):
    return unicode(crypt.encode(password))


class User(Base):
    """
    Application's user model.
    """
    __tablename__ = 'users'
    username = Column(Unicode(20), primary_key=True)
    name = Column(Unicode(50))
    email = Column(Unicode(50))
    salt = Column(Unicode(40))
    _password = Column('password', Unicode(60))


    @property
    def password(self):
        return self._password

    @password.setter
    def password(self, password):
        self.salt = ''.join(random.sample(
                (string.ascii_letters + string.digits) * 2,
                16))
        self._password = hash_password(self.salt + password)

    password = synonym('_password', descriptor=password)

    def __init__(self, username, password, name, email):
        self.username = username
        self.name = name
        self.email = email
        self.password = password

    @classmethod
    def get_by_username(cls, username):
        return DBSession.query(cls).filter(cls.username == username).first()

    @classmethod
    def check_password(cls, username, password):
        user = cls.get_by_username(username)
        if not user:
            return False
        return crypt.check(user.password, user.salt + password)

class LinkCheck(Base):
    __tablename__ = 'link_checks'
    check_id = Column(Integer, primary_key=True)
    active = Column(Boolean)
    check_css = Column(Boolean)
    check_html = Column(Boolean)
    scan_virus = Column(Boolean)
    warnings = Column(Boolean)
    warning_size= Column(Integer)
    anchors = Column(Boolean)
    cookies = Column(Boolean)
    cookiefile = Column(Unicode(256))
    ignore_url = Column(Unicode(256))
    no_follow_url = Column(Unicode(256))
    timeout = Column(Integer)
    pause = Column(Integer)
    recursion_level = Column(Integer)
    url = Column(Unicode(256))
    root_url = Column(Unicode(256))

    def __init__(self,  active,  check_css, check_html, scan_virus,
                warnings, warning_size, anchors, cookies, cookiefile,
                ignore_url, no_follow_url, timeout, pause, recursion_level,
                url, root_url):
        self.active = active
        self.anchors = anchors
        self.check_css = check_css
        self.check_html = check_html
        self.cookiefile = cookiefile
        self.cookies = cookies
        self.ignore_url = ignore_url
        self.no_follow_url = no_follow_url
        self.pause = pause
        self.recursion_level = recursion_level
        self.scan_virus = scan_virus
        self.timeout = timeout
        self.url = url
        self.warning_size = warning_size
        self.warnings = warnings
        self.root_url = root_url


class RootFactory(object):
    __acl__ = [
        (Allow, Everyone, 'view'),
        (Allow, Authenticated, 'edit')
    ]

    __name__= ''

    def __init__(self, request):
        pass



import csv
import subprocess
import string
import random
import os
import sys
import transaction

from sqlalchemy import engine_from_config

from ..utils import invalid_url, linkchecker_options

from pyramid.paster import (
    get_appsettings,
    setup_logging,
    )

from ..models import (
    DBSession,
    CheckedLink,
    LinkCheck,
    Base,
    CSV_HEADER,
    )


def usage(argv):
    cmd = os.path.basename(argv[0])
    print('usage: %s <config_uri> \n'
          '(example: "%s development.ini")' % (cmd, cmd))
    sys.exit(1)


def main(argv=sys.argv):
    if len(argv) != 2:
        usage(argv)
    config_uri = argv[1]
    setup_logging(config_uri)
    settings = get_appsettings(config_uri)
    engine = engine_from_config(settings, 'sqlalchemy.')
    DBSession.configure(bind=engine)
    Base.metadata.bind = engine
    linkchecks = DBSession.query(LinkCheck).filter_by(active=True).all()
    for linkcheck in linkchecks:
        filename = ''.join(random.sample(
            string.ascii_letters + string.digits, 16)) + '.csv'
        options = linkchecker_options(linkcheck)
        options.append("--file-output=csv/utf-8/" + filename)
        options.append(linkcheck.url)
        subprocess.call(options)
        with transaction.manager:
            DBSession.query(CheckedLink).filter(
                CheckedLink.parentname.like(linkcheck.root_url +'%')).delete(
                synchronize_session=False)
            DBSession.expire_all()
            fo = open(filename, 'rU')
            reader=csv.reader(fo, delimiter=';')
            line = reader.next()
            #the first lines are comments and are to be ignored
            while line[0].startswith('#'):
                line = reader.next()
            #the header comes after the comments
            #linkchecker < 8 does not have 'modified' field
            assert(line[:16] == CSV_HEADER[:16])
            try:
                for line in reader:
                    if line[0].startswith('#'):
                        continue
                    else:
                        line[10] = line[10].decode('UTF-8')
                    checked_link = CheckedLink( *line)
                    DBSession.add(checked_link)
            except:
                print "Error in line: ", line
        #os.remove(filename)



import hashlib
import urlparse
import re
from subprocess import Popen
import sys
import time
try:
    import simplejson as json
except ImportError:
    import json

from pyramid.response import Response
from pyramid.view import view_config
from pyramid.url import resource_url

from sqlalchemy.exc import DBAPIError

from .models import (
    DBSession,
    CheckedLink,
    User,
    LinkCheck,
    )

from pyramid.security import (
    authenticated_userid,
    remember,
    forget,
    )

from pyramid.httpexceptions import (
    HTTPMovedPermanently,
    HTTPFound,
    HTTPNotFound,
    )

import formencode

from pyramid_simpleform import Form
from pyramid_simpleform.renderers import FormRenderer

from .utils import invalid_url, API_KEY, linkchecker_options

class SecurePassword(formencode.validators.FancyValidator):

     min = 6
     non_letter = 2
     letter_regex = re.compile(r'[a-zA-Z]')

     messages = {
         'too_few': 'Your password must be longer than %(min)i '
                   'characters long',
         'non_letter': 'You must include at least %(non_letter)i '
                      'characters in your password',
         }

     def _convert_to_python(self, value, state):
         # _convert_to_python gets run before _validate_python.
         # Here we strip whitespace off the password, because leading
         # and trailing whitespace in a password is too elite.
         return value.strip()

     def _validate_python(self, value, state):
         if len(value) < self.min:
             raise Invalid(self.message("too_few", state,
                                        min=self.min),
                           value, state)
         non_letters = self.letter_regex.sub('', value)
         if len(non_letters) < self.non_letter:
             raise Invalid(self.message("non_letter",
                                         non_letter=self.non_letter),
                           value, state)




@view_config(route_name='home', renderer='templates/home.pt', permission='view')
def my_view(request):
    try:
        result = DBSession.query(CheckedLink.parentname).distinct().count()
    except DBAPIError:
        return Response(conn_err_msg, content_type='text/plain', status_int=500)
    logged_in = authenticated_userid(request)
    return {'result': result, 'project': 'liches', 'loggedin': logged_in}

conn_err_msg = """\
Pyramid is having a problem using your SQL database.  The problem
might be caused by one of the following things:

1.  You may need to run the "initialize_liches_db" script
    to initialize your database tables.  Check your virtual
    environment's "bin" directory for this script and try to run it.

2.  Your database server may not be running.  Check that the
    database server referred to by the "sqlalchemy.url" setting in
    your "development.ini" file is running.

After you fix the problem, please restart the Pyramid application to
try it again.
"""

@view_config(route_name='parenturl', renderer='templates/parenturl.pt', permission='view')
def parenturl_view(request):
    parenturl = request.params.get('url')
    error = invalid_url(parenturl)
    if error:
        return Response(error, content_type='text/plain', status_int=500)
    urlobj = urlparse.urlparse(parenturl)
    pagename = urlparse.urlunparse([urlobj.scheme, urlobj.netloc, urlobj.path, None, None, None])
    try:
        results = DBSession.query(CheckedLink).filter_by(parentname=parenturl).distinct().all()
    except DBAPIError:
        return Response(conn_err_msg, content_type='text/plain', status_int=500)
    if results is None:
        res = {'num': 0, 'urls': [], 'name': pagename}
    else:
        urls = []
        for url in results:
            urls.append({
                'urlname': url.urlname,
                'parentname': url.parentname,
                'baseref': url.baseref,
                'valid': url.valid,
                'result': url.result,
                'warning': url.warning,
                'info': url.info,
                'url': url.url,
                'line': url.line,
                'col': url.col,
                'name': url.name,
                'checktime': url.checktime,
                'dltime': url.dltime,
                'dlsize': url.dlsize,
                'cached': url.cached,
                'level': url.level,
                'modified': url.modified,})
        res = {'num': len(results), 'urls': urls, 'name':pagename}
    if request.params.get('format') == 'json':
        response =  Response(json.dumps(res))
        response.content_type='application/json'
        return response
    else:
        return res


@view_config(route_name='checkpages', renderer='templates/pages.pt', permission='view')
def checked_pages_view(request):
    parenturl = request.params.get('url')
    code = request.params.get('code')
    if code:
        invalid_only = None
    else:
        invalid_only = request.params.get('invalid') == "1"
    try:
        filter = []
        if parenturl:
            filter.append(CheckedLink.parentname.like(parenturl +'%'))
        if code:
            filter.append(CheckedLink.result == code)
        if invalid_only:
            filter.append(CheckedLink.valid == 'False')
        if filter:
            results = DBSession.query(CheckedLink.parentname
                ).filter( *filter
                ).distinct().all()
        else:
            results = DBSession.query(CheckedLink.parentname).distinct().all()
    except DBAPIError:
        return Response(conn_err_msg, content_type='text/plain', status_int=500)
    codes = DBSession.query(CheckedLink.result).distinct().all()
    if results is None:
        res = {'num': 0, 'urls': [], 'name': pagename, 'codes': codes,
            'code': code, 'invalid': invalid_only}
    else:
        urls = []
        for url in results:
            urls.append([url[0],
            resource_url(request.context, request, 'checkurl', query={'url': url[0]})])
        res = {'num': len(results), 'urls': urls, 'name':parenturl,
            'codes': codes, 'code':code, 'invalid': invalid_only}
    if request.params.get('format') == 'json':
        response =  Response(json.dumps(res))
        response.content_type='application/json'
        return response
    else:
        return res

@view_config(route_name='linkcheck', renderer='templates/checklink.pt', permission='view')
def check_url(request):
    url = request.params.get('url')
    key = request.params.get('key')
    error = invalid_url(url)
    if error:
        return Response(error, content_type='text/plain', status_int=500)
    t = int(time.time()/100)
    valid = False
    for i in range(-1,2):
        if hashlib.md5(str(t+i) +API_KEY + url).hexdigest() == key:
            valid = True
            break
    if valid:
        process = Popen(['bin/checkpage', sys.argv[1], url])
        result = {'status': 'linkcheck initialized', 'name': url}
    else:
        return Response('illegal or missing key', content_type='text/plain', status_int=403)
    if request.params.get('format') == 'json':
        response =  Response(json.dumps(result))
        response.content_type='application/json'
        return response
    else:
        return result


@view_config(permission='view', route_name='login')
def login_view(request):
    main_view = request.route_url('home')
    came_from = request.params.get('came_from', main_view)

    post_data = request.POST
    if 'submit' in post_data:
        login = post_data['login']
        password = post_data['password']

        if User.check_password(login, password):
            headers = remember(request, login)
            request.session.flash(u'Logged in successfully.')
            return HTTPFound(location=came_from, headers=headers)

    request.session.flash(u'Failed to login.')
    return HTTPFound(location=came_from)

@view_config(permission='edit', route_name='logout')
def logout_view(request):
    request.session.invalidate()
    request.session.flash(u'Logged out successfully.')
    headers = forget(request)
    return HTTPFound(location=request.route_url('home'), headers=headers)



class RegistrationSchema(formencode.Schema):
    allow_extra_fields = True
    username = formencode.validators.PlainText(not_empty=True)
    #password = formencode.validators.PlainText(not_empty=True)
    email = formencode.validators.Email(resolve_domain=False)
    name = formencode.validators.String(not_empty=True)
    password = SecurePassword()
    confirm_password = formencode.validators.String(not_empty=True)
    chained_validators = [
        formencode.validators.FieldsMatch('password', 'confirm_password')
    ]


@view_config(permission='edit', route_name='register',
             renderer='templates/user_add.pt')
def user_add(request):
    form = Form(request, schema=RegistrationSchema)
    redirect_url = request.route_url('home')
    if 'form.submitted' in request.POST and form.validate():
        session = DBSession()
        username = form.data['username']
        user = User(
            username=username,
            password=form.data['password'],
            name=form.data['name'],
            email=form.data['email']
        )
        session.add(user)
        headers = remember(request, username)
        return HTTPFound(location=redirect_url, headers=headers)
    elif 'form.canceled' in request.POST:
        return HTTPFound(location=redirect_url)
    return {
        'form': FormRenderer(form),
    }

class UserPreferencesSchema(formencode.Schema):
    allow_extra_fields = True
    old_password = formencode.validators.PlainText()
    email = formencode.validators.Email(resolve_domain=False)
    name = formencode.validators.String(not_empty=True)
    new_password = SecurePassword()
    confirm_password = formencode.validators.String()
    chained_validators = [
        formencode.validators.FieldsMatch('new_password', 'confirm_password')
    ]

@view_config(permission='edit', route_name='preferences',
             renderer='templates/user_edit.pt')
def user_preferences(request):
    logged_in = authenticated_userid(request)
    redirect_url = request.route_url('home')
    try:
        user = DBSession.query(User).filter_by(username=logged_in).first()
    except DBAPIError:
        return Response(conn_err_msg, content_type='text/plain', status_int=500)
    form = Form(request, schema=UserPreferencesSchema)
    if 'form.submitted' in request.POST and form.validate():
        if form.data.get('new_password'):
            if User.check_password(logged_in, form.data['old_password']):
                user.password = form.data['new_password']
        user.email = form.data.get('email')
        user.name = form.data.get('name')
        DBSession.add(user)
        return HTTPFound(location=redirect_url)
    elif 'form.canceled' in request.POST:
        return HTTPFound(location=redirect_url)
    else:
        return {'user': user, 'form': FormRenderer(form)}


class LinkCheckSchema(formencode.Schema):
    allow_extra_fields = True
    url = formencode.validators.URL(not_empty=True)
    root_url = formencode.validators.URL(not_empty=True)
    recursion_level = formencode.validators.Int()
    active = formencode.validators.Bool()
    check_css = formencode.validators.Bool()
    check_html = formencode.validators.Bool()
    scan_virus = formencode.validators.Bool()
    warnings = formencode.validators.Bool()
    anchors = formencode.validators.Bool()
    cookies = formencode.validators.Bool()
    timeout = formencode.validators.Int()
    pause = formencode.validators.Int()

@view_config(permission='edit', route_name='addlinkcheck',
             renderer='templates/linkcheck_add.pt')
def linkcheck_add(request):
    form = Form(request, schema=LinkCheckSchema)
    redirect_url = request.route_url('linkchecks')
    if 'form.submitted' in request.POST and form.validate():
        session = DBSession()
        url = form.data['url']
        linkcheck = LinkCheck(
            url=url,
            root_url=form.data['root_url'],
            recursion_level=form.data.get('recursion_level'),
            active=form.data.get('active'),
            check_css=form.data.get('check_css'),
            check_html=form.data.get('check_html'),
            scan_virus=form.data.get('scan_virus'),
            warnings=form.data.get('warnings'),
            warning_size=form.data.get('warning_size'),
            anchors=form.data.get('anchors'),
            cookies=form.data.get('coockies'),
            cookiefile=form.data.get('cookiefile'),
            ignore_url=form.data.get('ignore_url'),
            no_follow_url=form.data.get('no_follow_url'),
            timeout=form.data.get('timeout'),
            pause=form.data.get('pause'),
        )
        session.add(linkcheck)
        return HTTPFound(location=redirect_url)
    elif 'form.canceled' in request.POST:
        return HTTPFound(location=redirect_url)
    return {
        'form': FormRenderer(form),
    }

@view_config(permission='edit', route_name='editlinkcheck',
             renderer='templates/linkcheck_edit.pt')
def linkcheck_edit(request):
    check_id = request.matchdict['check_id']
    page = DBSession.query(LinkCheck).filter_by(check_id=check_id).first()
    if page is None:
        return HTTPNotFound('No such page')

    form = Form(request, schema=LinkCheckSchema)
    redirect_url = request.route_url('linkchecks')
    if 'form.submitted' in request.POST and form.validate():
        page.url=form.data['url']
        page.root_url=form.data['root_url']
        page.recursion_level=form.data.get('recursion_level')
        page.active=form.data.get('active')
        page.check_css=form.data.get('check_css')
        page.check_html=form.data.get('check_html')
        page.scan_virus=form.data.get('scan_virus')
        page.warnings=form.data.get('warnings')
        page.warning_size=form.data.get('warning_size')
        page.anchors=form.data.get('anchors')
        page.cookies=form.data.get('coockies')
        page.cookiefile=form.data.get('cookiefile')
        page.ignore_url=form.data.get('ignore_url')
        page.no_follow_url=form.data.get('no_follow_url')
        page.timeout=form.data.get('timeout')
        page.pause=form.data.get('pause')
        return HTTPFound(location=redirect_url)
    elif 'form.canceled' in request.POST:
        return HTTPFound(location=redirect_url)
    elif 'form.deleted' in request.POST:
        DBSession.delete(page)
        return HTTPFound(location=redirect_url)
    else:
        return {
            'form': FormRenderer(form), 'data': page,
        }



@view_config(permission='edit', route_name='linkchecks',
             renderer='templates/linkchecks.pt')
def linkchecks_view(request):
    try:
        results = DBSession.query(LinkCheck).all()
    except DBAPIError:
        return Response(conn_err_msg, content_type='text/plain', status_int=500)
    if results is None:
        res = {'urls': []}
    else:
        urls = []
        for linkcheck in results:
            if linkcheck.active:
                start_url = linkcheck.url
            else:
                start_url = 'inactive'
            urls.append({
                'name': linkcheck.root_url,
                'start': start_url,
                'options': ' '.join(linkchecker_options(linkcheck)),
                'url': request.route_url('editlinkcheck', check_id=linkcheck.check_id),
                })
        res ={'urls': urls}
    if request.params.get('format') == 'json':
        response =  Response(json.dumps(res))
        response.content_type='application/json'
        return response
    else:
        return res



import sys
import ConfigParser
import urlparse
import string
import random
import logging

logger = logging.getLogger(__name__)

config = ConfigParser.SafeConfigParser()
config.read(sys.argv[1])
try:
    API_KEY = config.get('liches','api_key')
except:
    API_KEY = None
if not API_KEY:
    API_KEY = ''.join(random.sample(string.ascii_letters + string.digits,
                16))
    logger.warn('API Key: %s' % API_KEY)


def invalid_url(url):
    if not url:
        return 'Required parameter url is missing'
    urlobj = urlparse.urlparse(url)
    if urlobj.scheme not in ['http', 'https']:
        return 'url must start with http:// or https://'
    if not urlobj.hostname:
        return 'Required hostname is missing'
    return False

def linkchecker_options(linkcheck):
    options = []
    if not linkcheck.active:
        return options
    else:
        options.append('bin/linkchecker')
    if linkcheck.anchors:
        options.append('--anchors')
    if linkcheck.check_css:
        options.append('--check-css')
    if linkcheck.check_html:
        options.append('--check-html')
    if linkcheck.cookies:
        options.append(' --cookies')
    if linkcheck.scan_virus:
        options.append('--scan-virus')
    if not linkcheck.warnings:
        options.append('--no-warnings')
    if linkcheck.ignore_url:
        for line in linkcheck.ignore_url.splitlines():
            options.append('--ignore-url=%s' % line )
    if linkcheck.no_follow_url:
        for line in linkcheck.no_follow_url.splitlines():
            options.append('--no-follow-url=%s' % line )
    if linkcheck.recursion_level:
        options.append('--recursion-level=%i' % linkcheck.recursion_level)
    if linkcheck.pause:
        options.append('--pause=%i' % linkcheck.pause)
    if linkcheck.warning_size:
        options.append('--warning-size-bytes=%i' % linkcheck.warning_size)
    if linkcheck.timeout:
        options.append('--timeout=%i' % linkcheck.timeout)
    return options


